This is a very simple Spring Boot Java application which demonstrating the use of Solace Messaging on Cloud Foundry.  This sample depends on the Solace Messaging API for Java. See the below for how to obtain this API.

See [Solace Developer Blog][Solace_Blog] for an overview of this application and how to use it.


## Obtaining the Solace API ##

The Java API library can be downloaded [here][Solace_downloads]. The Java API is distributed as a zip file containing the required jars, API documentation, and examples. 

Copy the `sol-common` and `sol-jcsmp` from the API `libs` directory into the `libs` directory of this project. Or update the `build.gradle` file appropriately if you have a different environment setup.

## Building ##

The following command will build the Cloud Foundry package

    ./gradlew assemble
    
For convenience you can also build an Eclipse project as follows:

    ./gradlew eclipse
    

## Deploying to Cloud Foundry ##

This application can be deployed using the Cloud Foundry CLI. Refer to the Cloud Foundry documentation for instructions on installing the [Cloud Foundry 'cf'][cf_cli] command.

Note: You must correctly target and login to a Cloud Foundry instance for the following to work.

    cf push --no-start 
    cf cups solace-user-provided-messaging -p "smfUri, msgVpn, username, password"
    cf bind-service solace-cf-intro-java-app solace-user-provided-messaging
    cf start solace-cf-intro-java-app

The deployment is controlled by the included `manifest.yml`. This file contains the application parameters used by Cloud Foundry. Cloud Foundry will assign your application a unique URL during `cf push`. This can be viewed by running `cf apps`. For example: 

    cf apps
    ...
    name                           requested state   instances   memory   disk   urls
    solace-cf-intro-java-app       started           1/1         256M     1G     solace-cf-intro-java-app.X.Y.Z


## Basic Usage ##

This application exposes a REST API to try out Solace messaging. Below are some example commands. See the [blog post][Solace_Blog] for more details. Replace `X.Y.Z` in the following with the correct URL to match your environment. The username and password in this sample is `solacedemo/solacedemo`.

- Adding a Subscription of `a/b/c/d`.

```
curl -X POST -H "Authorization: Basic c29sYWNlZGVtbzpzb2xhY2VkZW1v" -H "Content-Type: application/json" -d '{"subscription": "a/b/c/d"}' http://solace-cf-intro-java-app.X.Y.Z/subscription
```

- Sending a message with contents `My demo message` to the topic `a/b/c/d`.
 
```
curl -X POST -H "Authorization: Basic c29sYWNlZGVtbzpzb2xhY2VkZW1v" -H "Content-Type: application/json" -d '{"topic": "a/b/c/d", "body": "My demo message"}' http://solace-cf-intro-java-app.X.Y.Z/message
```

- Retrieving the last message received:
 
```
curl -X GET -H "Authorization: Basic c29sYWNlZGVtbzpzb2xhY2VkZW1v"  http://solace-cf-intro-java-app.X.Y.Z/message
```

## Questions and issues ##

Please ask questions or raise any issues in the [Solace Developer Community][Solace_Community].

[cf_cli]: https://docs.cloudfoundry.org/devguide/cf-cli/
[Solace_downloads]: http://dev.solacesystems.com/downloads
[Solace_Blog]: http://dev.solacesystems.com
[Solace_Community]: http://dev.solacesystems.com/community/
